sqlobject.inheritance.tests.test_foreignKey module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_foreignKey module

class `sqlobject.inheritance.tests.test_foreignKey.` `EmployeeWithNotes`(**kw)

  Bases: `sqlobject.inheritance.tests.test_foreignKey.PersonWithNotes`

  property `firstName`
  `j` = employee_with_notes
  property `lastName`
  property `note`
  property `paper`
  property `paperID`
  `q` = employee_with_notes
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'EmployeeWithNotes'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.PersonWithNotes`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.EmployeeWithNotes`

    `table` = 'employee_with_notes'

class `sqlobject.inheritance.tests.test_foreignKey.` `Note`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = note
  `q` = note
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.Note`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'note'
  property `text`

class `sqlobject.inheritance.tests.test_foreignKey.` `Paper`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `content`
  `j` = paper
  `q` = paper
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.Paper`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'paper'

class `sqlobject.inheritance.tests.test_foreignKey.` `PersonWithNotes`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `childName`
  property `firstName`
  `j` = person_with_notes
  property `lastName`
  property `note`
  property `noteID`
  `q` = person_with_notes
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'EmployeeWithNotes': <class 'sqlobject.inheritance.tests.test_foreignKey.EmployeeWithNotes'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.PersonWithNotes`

    `table` = 'person_with_notes'

class `sqlobject.inheritance.tests.test_foreignKey.` `SOTestInhBase`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `childName`
  `j` = so_test_inh_base
  `q` = so_test_inh_base
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'SOTestInhFKey': <class 'sqlobject.inheritance.tests.test_foreignKey.SOTestInhFKey'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.SOTestInhBase`

    `table` = 'so_test_inh_base'

class `sqlobject.inheritance.tests.test_foreignKey.` `SOTestInhFKey`(**kw)

  Bases: `sqlobject.inheritance.tests.test_foreignKey.SOTestInhBase`

  property `base`
  property `baseID`
  property `childName`
  `j` = so_test_inh_f_key
  `q` = so_test_inh_f_key
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'SOTestInhFKey'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.SOTestInhBase`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_foreignKey.SOTestInhFKey`

    `table` = 'so_test_inh_f_key'

`sqlobject.inheritance.tests.test_foreignKey.` `test_foreignKey`()

`sqlobject.inheritance.tests.test_foreignKey.` `test_foreignKey2`()